@@ -8,8 +8,6 @@ def guessGame_1_10_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -17,6 +15,8 @@ def guessGame_1_10_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
         
 def guessGame_1_100_Easy():
@@ -28,12 +28,12 @@ def guessGame_1_100_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
                 print('you\'s guess are too big')
+            elif ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
@@ -57,6 +57,8 @@ def guessGame_1_1000_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 def guessGame_1_10000_Easy():
     number = random.randint(1,10000)
     ettempt = 0
@@ -66,8 +68,6 @@ def guessGame_1_10000_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -75,6 +75,8 @@ def guessGame_1_10000_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 def guessGame_1_100000_Easy():
     number = random.randint(1,100000)
     ettempt = 0
@@ -84,15 +86,17 @@ def guessGame_1_100000_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
                 print('you\'s guess are too big')
+            elif ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 def guessGame_1_1000000_Easy():
     number = random.randint(1,1000000)
     ettempt = 0
@@ -102,8 +106,6 @@ def guessGame_1_1000000_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -111,6 +113,8 @@ def guessGame_1_1000000_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 def guessGame_1_10000000_Easy():
     number = random.randint(1,10000000)
     ettempt = 0
@@ -120,8 +124,6 @@ def guessGame_1_10000000_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -129,6 +131,8 @@ def guessGame_1_10000000_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 def guessGame_1_100000000_Easy():
     number = random.randint(1,100000000)
     ettempt = 0
@@ -138,8 +142,6 @@ def guessGame_1_100000000_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -147,7 +149,8 @@ def guessGame_1_100000000_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
-
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 def guessGame_1_1000000000_Easy():
     number = random.randint(1,10000000000)
     ettempt = 0
@@ -157,8 +160,6 @@ def guessGame_1_1000000000_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -166,7 +167,8 @@ def guessGame_1_1000000000_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
-
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 def guessGame_1_10000000000_Easy():
     number = random.randint(1,10000000000)
@@ -177,8 +179,6 @@ def guessGame_1_10000000000_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -186,6 +186,8 @@ def guessGame_1_10000000000_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 def guessGame_1_100000000000_Easy():
     number = random.randint(1,100000000000)
@@ -196,8 +198,6 @@ def guessGame_1_100000000000_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -205,6 +205,8 @@ def guessGame_1_100000000000_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 
 def guessGame_1_999999999999_Easy():
@@ -216,8 +218,6 @@ def guessGame_1_999999999999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -225,6 +225,8 @@ def guessGame_1_999999999999_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 
 def guessGame_1_9_Easy():
@@ -236,8 +238,6 @@ def guessGame_1_9_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -245,6 +245,8 @@ def guessGame_1_9_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 
 def guessGame_1_99_Easy():
@@ -256,8 +258,6 @@ def guessGame_1_99_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -265,6 +265,8 @@ def guessGame_1_99_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 
 def guessGame_1_999_Easy():
@@ -276,8 +278,6 @@ def guessGame_1_999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -285,6 +285,8 @@ def guessGame_1_999_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 
 def guessGame_1_9999_Easy():
@@ -296,8 +298,6 @@ def guessGame_1_9999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -305,6 +305,8 @@ def guessGame_1_9999_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 def guessGame_1_99999_Easy():
     number = random.randint(1,99999)
@@ -315,16 +317,17 @@ def guessGame_1_99999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
                 print('you\'s guess are too big')
+            elif ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
-
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 def guessGame_1_999999_Easy():
     number = random.randint(1,999999)
@@ -335,15 +338,17 @@ def guessGame_1_999999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
                 print('you\'s guess are too big')
+            elif ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 def guessGame_1_9999999_Easy():
     number = random.randint(1,9999999)
@@ -354,8 +359,6 @@ def guessGame_1_9999999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -363,6 +366,8 @@ def guessGame_1_9999999_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 def guessGame_1_99999999_Easy():
     number = random.randint(1,99999999)
@@ -373,8 +378,6 @@ def guessGame_1_99999999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -382,6 +385,8 @@ def guessGame_1_99999999_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 def guessGame_1_999999999_Easy():
     number = random.randint(1,999999999)
@@ -392,15 +397,14 @@ def guessGame_1_999999999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
                 print('you\'s guess are too big')
             else:
                 print('you\'s guess are too small')
-            ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 
 def guessGame_1_9999999999_Easy():
@@ -412,8 +416,6 @@ def guessGame_1_9999999999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -421,6 +423,8 @@ def guessGame_1_9999999999_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
 
 def guessGame_1_99999999999_Easy():
     number = random.randint(1,99999999999)
@@ -431,8 +435,6 @@ def guessGame_1_99999999999_Easy():
         if number == int(guess):
             print('太棒了，你猜对了!')
             Round = Round - 1
-        elif ettempt == 3:
-            print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
             if number < int(guess):
@@ -440,4 +442,5 @@ def guessGame_1_99999999999_Easy():
             else:
                 print('you\'s guess are too small')
             ettempt = ettempt + 1
-
+            if ettempt == 3:
+                print('sorry wrong,the collect int is: '+str(number))
